==> mingw-w64-ossia-score-3.1.13-1.src.tar.zst: ossia-score-3.1.13/src/plugins/score-plugin-protocols/Protocols/Wiimote/WiimoteProtocolFactory.cpp <==

#include "WiimoteProtocolFactory.hpp"

#include "WiimoteDevice.hpp"
#include "WiimoteProtocolSettingsWidget.hpp"
#include "WiimoteSpecificSettings.hpp"

#include <Explorer/DocumentPlugin/DeviceDocumentPlugin.hpp>

#include <QObject>

namespace Protocols
{

QString WiimoteProtocolFactory::prettyName() const noexcept
{
  return QObject::tr("Wiimote");
}

QString WiimoteProtocolFactory::category() const noexcept
{
  return StandardCategories::hardware;
}

Device::DeviceInterface* WiimoteProtocolFactory::makeDevice(
    const Device::DeviceSettings& settings, const Explorer::DeviceDocumentPlugin& plugin,
    const score::DocumentContext& ctx)
{
  return new WiimoteDevice{settings, plugin.networkContext()};
}

const Device::DeviceSettings& WiimoteProtocolFactory::defaultSettings() const noexcept
{
  static const Device::DeviceSettings& settings = [&]() {
    Device::DeviceSettings s;
    s.protocol = concreteKey();
    s.name = "Wiimote";
    WiimoteSpecificSettings settings;
    s.deviceSpecificSettings = QVariant::fromValue(settings);
    return s;
  }();

  return settings;
}

Device::ProtocolSettingsWidget* WiimoteProtocolFactory::makeSettingsWidget()
{
  return new WiimoteProtocolSettingsWidget;
}

QVariant
WiimoteProtocolFactory::makeProtocolSpecificSettings(const VisitorVariant& visitor) const
{
  return makeProtocolSpecificSettings_T<WiimoteSpecificSettings>(visitor);
}

void WiimoteProtocolFactory::serializeProtocolSpecificSettings(
    const QVariant& data, const VisitorVariant& visitor) const
{
  serializeProtocolSpecificSettings_T<WiimoteSpecificSettings>(data, visitor);
}

bool WiimoteProtocolFactory::checkCompatibility(
    const Device::DeviceSettings& a, const Device::DeviceSettings& b) const noexcept
{
  return false;
}

}

==> mingw-w64-ossia-score-3.7.1-3.src.tar.zst: ossia-score-3.7.1/src/plugins/score-plugin-protocols/Protocols/Wiimote/WiimoteProtocolFactory.cpp <==

#include "WiimoteProtocolFactory.hpp"

#include "WiimoteDevice.hpp"
#include "WiimoteProtocolSettingsWidget.hpp"
#include "WiimoteSpecificSettings.hpp"

#include <Explorer/DocumentPlugin/DeviceDocumentPlugin.hpp>

#include <QObject>
#include <QUrl>

namespace Protocols
{

QString WiimoteProtocolFactory::prettyName() const noexcept
{
  return QObject::tr("Wiimote");
}

QString WiimoteProtocolFactory::category() const noexcept
{
  return StandardCategories::hardware;
}

QUrl WiimoteProtocolFactory::manual() const noexcept
{
  return QUrl("https://ossia.io/score-docs/devices/wiimote-device.html");
}

Device::DeviceInterface* WiimoteProtocolFactory::makeDevice(
    const Device::DeviceSettings& settings, const Explorer::DeviceDocumentPlugin& plugin,
    const score::DocumentContext& ctx)
{
  return new WiimoteDevice{settings, plugin.networkContext()};
}

const Device::DeviceSettings& WiimoteProtocolFactory::defaultSettings() const noexcept
{
  static const Device::DeviceSettings& settings = [&]() {
    Device::DeviceSettings s;
    s.protocol = concreteKey();
    s.name = "Wiimote";
    WiimoteSpecificSettings settings;
    s.deviceSpecificSettings = QVariant::fromValue(settings);
    return s;
  }();

  return settings;
}

Device::ProtocolSettingsWidget* WiimoteProtocolFactory::makeSettingsWidget()
{
  return new WiimoteProtocolSettingsWidget;
}

QVariant
WiimoteProtocolFactory::makeProtocolSpecificSettings(const VisitorVariant& visitor) const
{
  return makeProtocolSpecificSettings_T<WiimoteSpecificSettings>(visitor);
}

void WiimoteProtocolFactory::serializeProtocolSpecificSettings(
    const QVariant& data, const VisitorVariant& visitor) const
{
  serializeProtocolSpecificSettings_T<WiimoteSpecificSettings>(data, visitor);
}

bool WiimoteProtocolFactory::checkCompatibility(
    const Device::DeviceSettings& a, const Device::DeviceSettings& b) const noexcept
{
  return true;
}
}
